Bumped Mbed FW version to 01.20.0080

Revision:
19:09d58952b65d
Parent:
18:cbf514cce921
Child:
20:f94859dd2ca0
--- a/main.cpp	Tue Aug 20 12:19:31 2019 +0000
+++ b/main.cpp	Mon Sep 09 05:57:43 2019 +0000
@@ -31,40 +31,7 @@
 CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
-Copyright 2017 (c) Analog Devices, Inc.
 
-All rights reserved.
-
-Redistribution and use in source and binary forms, with or without
-modification, are permitted provided that the following conditions are met:
-  - Redistributions of source code must retain the above copyright
-    notice, this list of conditions and the following disclaimer.
-  - Redistributions in binary form must reproduce the above copyright
-    notice, this list of conditions and the following disclaimer in
-    the documentation and/or other materials provided with the
-    distribution.
-  - Neither the name of Analog Devices, Inc. nor the names of its
-    contributors may be used to endorse or promote products derived
-    from this software without specific prior written permission.
-  - The use of this software may or may not infringe the patent rights
-    of one or more patent holders. This license does not release you
-    from the requirement that you obtain separate licenses from these
-    patent holders to use this software.
-  - Use of the software either in source or binary form, must be run
-    on or directly connected to an Analog Devices Inc. component.
-
-THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR
-IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT,
-MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
-IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT,
-INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-LIMITED TO, INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR
-SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
-CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
-OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
  *****************************************************************************/
 /*!
  ******************************************************************************
@@ -93,8 +60,9 @@
 extern ADMW_CONFIG multichannel_singlecycle_config;
 extern ADMW_CONFIG sensor2_bridge_4w_load_cell_config;
 extern ADMW_CONFIG config;
+extern ADMW_CONFIG multichannel_thermocoupleAndHumidity;
 /* Change the following pointer to select any of the configurations above */
-static ADMW_CONFIG *pSelectedConfig = &sensor2_bridge_4w_load_cell_config;
+static ADMW_CONFIG *pSelectedConfig = &i2c0_sensirionSHT3X_config;
 
 static ADMW_CONNECTION connectionInfo = PLATFORM_CONNECTION_INFO;
 
@@ -108,7 +76,7 @@
     bool bDeviceReady;
     
     /*
      * Open an ADI Sense device instance.
      */
     res = admw_Open(0, &connectionInfo, &hDevice);
     if (res != ADMW_SUCCESS)
@@ -118,9 +86,9 @@
     }
     
     /*
      * Reset the given ADI Sense device....
      */
-    ADMW_LOG_INFO("Resetting ADI Sense device, please wait...");
+    ADMW_LOG_INFO("Resetting ADMW1001 device, please wait...");
     res = admw_Reset(hDevice);
     if (res != ADMW_SUCCESS)
     {
@@ -139,7 +107,7 @@
             return res;
         }
     } while (! bDeviceReady);
-    ADMW_LOG_INFO("ADI Sense device ready");
+    ADMW_LOG_INFO("ADMW1001 device ready");
     /*
      * Write configuration settings to the device registers.
      * Settings are not applied until admw_ApplyConfigUpdates() is called.
@@ -108,7 +76,7 @@
     
     /*
-     * Open an ADI Sense device instance.
+     * Open an ADMW1001 device instance.
      */
     res = admw_Open(0, &connectionInfo, &hDevice);
@@ -118,9 +86,9 @@
     
     /*
-     * Reset the given ADI Sense device....
+     * Reset the given ADMW1001 device....
      */